@@ -24,7 +24,8 @@ e0.mcmc.sampling <- function(mcmc, thin=1, start.iter=2, verbose=FALSE, verbose.
 	for(iter in start.iter:niter) {
 		if(verbose.iter > 0 && (iter %% verbose.iter == 0))
 			cat('\nIteration:', iter, '--', date())
-				
+		unblock.gtk('bDem.e0mcmc')
+
 		# Update Triangle, k, z using Gibbs sampler
 		###########################################
 		sum.Trkz.c <- rowSums(mcenv$Triangle.c)
@@ -84,6 +85,8 @@ e0.mcmc.sampling <- function(mcmc, thin=1, start.iter=2, verbose=FALSE, verbose.
 	return(resmc)
 }
 
+unblock.gtk <- function(...) bayesTFR:::unblock.gtk(...)
+
 e0.mcmc.sampling.extra <- function(mcmc, mcmc.list, countries, posterior.sample,
 											 iter=NULL, burnin=2000, 
 											 verbose=FALSE, verbose.iter=100) {
@@ -118,6 +121,7 @@ e0.mcmc.sampling.extra <- function(mcmc, mcmc.list, countries, posterior.sample,
 	for(iter in 1:niter) {
 		if(verbose.iter > 0 && (iter %% verbose.iter == 0))
 			cat('\nIteration:', iter, '--', date())
+		unblock.gtk('bDem.e0mcmcExtra')
 		# set hyperparameters for this iteration
         for (par in hyperparameter.names) {
         	if(is.null(dim(hyperparameters[[par]]))) {
